/* Copyright (C) 2018-2022 |Meso|Star> (contact@meso-star.com)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>. */

#ifndef SDIS_GREEN_H
#define SDIS_GREEN_H

/* The number of the file format as presented thereafter */
#define GREEN_FILE_FORMAT_VERSION 4

/* The max length for a description name */
#define DESC_NAME_MAX_LEN 63

/* The string at the beginning of a binary Green file that identifies it */
#define BIN_FILE_IDENT_STRING "GREEN_BIN_FILE:"

/* The header of a binary Green file */
struct green_file_header {
  char green_string[sizeof(BIN_FILE_IDENT_STRING)];
  unsigned file_format_version;
  unsigned description_count;
  unsigned solid_count;
  unsigned fluid_count;
  unsigned hbound_count;
  unsigned tbound_count;
  unsigned fbound_count;
  unsigned sfconnect_count;
  unsigned ssconnect_count;
  size_t ok_count;
  size_t failed_count;
  double ambient_radiative_temperature;
  double ambient_radiative_temperature_reference;
  double time_range[2];
};

/* Different types of descriptions */
enum green_description_type {
  GREEN_MAT_SOLID,
  GREEN_MAT_FLUID,
  GREEN_BOUND_H,
  GREEN_BOUND_T,
  GREEN_BOUND_F,
  GREEN_SOLID_FLUID_CONNECT,
  GREEN_SOLID_SOLID_CONNECT
};

struct green_solid {
  char name[DESC_NAME_MAX_LEN+1];
  double conductivity;
  double volumic_mass;
  double calorific_capacity;
  double volumic_power;
  double initial_temperature;
  double imposed_temperature;
};

struct green_fluid {
  char name[DESC_NAME_MAX_LEN+1];
  double volumic_mass;
  double calorific_capacity;
  double initial_temperature;
  double imposed_temperature;
};

struct green_h_boundary {
  char name[DESC_NAME_MAX_LEN+1];
  double reference_temperature;
  double emissivity;
  double specular_fraction;
  double convection_coefficient;
  double imposed_temperature;
};

struct green_t_boundary {
  char name[DESC_NAME_MAX_LEN+1];
  double imposed_temperature;
};

struct green_f_boundary {
  char name[DESC_NAME_MAX_LEN+1];
  double imposed_flux;
};

struct green_solid_fluid_connect {
  char name[DESC_NAME_MAX_LEN+1];
  double reference_temperature;
  double emissivity;
  double specular_fraction;
  double convection_coefficient;
};

struct green_solid_solid_connect {
  char name[DESC_NAME_MAX_LEN+1];
  double thermal_contact_resistance;
};

struct green_description {
  enum green_description_type type;
  union {
    struct green_fluid fluid;
    struct green_solid solid;
    struct green_t_boundary t_boundary;
    struct green_f_boundary f_boundary;
    struct green_h_boundary h_boundary;
    struct green_solid_fluid_connect sf_connect;
    struct green_solid_solid_connect ss_connect;
  } d;
};

/* The header of a Green sample */
struct green_sample_header {
  unsigned pw_count;
  unsigned fx_count;
  unsigned sample_end_description_id;
  int at_initial;
};

#endif
