# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the RSys devel. Once done this will define:
#   - RSys_FOUND: system has RSys
#   - RSys_INCLUDE_DIR: the include directory
#   - RSys: Link this to use rsys

# Look for library header
find_path(RSys_INCLUDE_DIR rsys/rsys_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(RSys_LIBRARY CACHE)
unset(RSys_LIBRARY_RELEASE CACHE)
unset(RSys_LIBRARY_DEBUG CACHE)
unset(RSys_LIBRARY_RELWITHDEBINFO CACHE)
unset(RSys_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(RSys_LIBRARY_RELEASE
  rsys
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library rsys used during release builds.")
find_library(RSys_LIBRARY_DEBUG
  rsys-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library rsys used during debug builds.")
find_library(RSys_LIBRARY_RELWITHDEBINFO
  rsys-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library rsys used during release with debug info builds.")
find_library(RSys_LIBRARY_MINSIZEREL
  rsys-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library rsys used during minsize builds.")

# Define the generic rsys library
if(RSys_LIBRARY_RELEASE)
  set(RSys_LIBRARY ${RSys_LIBRARY_RELEASE})
elseif(RSys_LIBRARY_RELWITHDEBINFO)
  set(RSys_LIBRARY ${RSys_LIBRARY_RELWITHDEBINFO})
elseif(RSys_LIBRARY_MINSIZEREL)
  set(RSys_LIBRARY ${RSys_LIBRARY_MINSIZEREL})
elseif(RSys_LIBRARY_DEBUG)
  set(RSys_LIBRARY ${RSys_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT RSys_LIBRARY_${_cfg})
    get_property(_doc CACHE RSys_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(RSys_LIBRARY_${_cfg} 
      ${RSys_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(RSys SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(RSys PROPERTIES
  ${_import_prop} ${RSys_LIBRARY}
  ${_import_prop}_RELEASE ${RSys_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${RSys_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${RSys_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${RSys_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${RSys_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(RSys DEFAULT_MSG
  RSys_INCLUDE_DIR
  RSys_LIBRARY)

