# Copyright (C) 2013-2017, 2021 Vincent Forest (vaplv@free.fr)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

cmake_minimum_required(VERSION 3.1)
include(SelectLibraryConfigurations)

# Try to find the Stardis devel. Once done this will define:
#   - Stardis_FOUND: system has Stardis
#   - Stardis_INCLUDE_DIR: the include directory
#   - Stardis: Link this to use sdis

# Look for library header
find_path(Stardis_INCLUDE_DIR sdis_version.h)

# Look for Release, Debug, RelWithDebInfo and MinSizeRel libraries
unset(Stardis_LIBRARY CACHE)
unset(Stardis_LIBRARY_RELEASE CACHE)
unset(Stardis_LIBRARY_DEBUG CACHE)
unset(Stardis_LIBRARY_RELWITHDEBINFO CACHE)
unset(Stardis_LIBRARY_MINSIZEREL CACHE)

# Find per configuration type libraries
find_library(Stardis_LIBRARY_RELEASE
  sdis
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library sdis used during release builds.")
find_library(Stardis_LIBRARY_DEBUG
  sdis-dbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library sdis used during debug builds.")
find_library(Stardis_LIBRARY_RELWITHDEBINFO
  sdis-rdbg
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library sdis used during release with debug info builds.")
find_library(Stardis_LIBRARY_MINSIZEREL
  sdis-mszr
  PATH_SUFFIXES bin Bin BIN
  DOC "Path to the library sdis used during minsize builds.")

# Define the generic sdis library
if(Stardis_LIBRARY_RELEASE)
  set(Stardis_LIBRARY ${Stardis_LIBRARY_RELEASE})
elseif(Stardis_LIBRARY_RELWITHDEBINFO)
  set(Stardis_LIBRARY ${Stardis_LIBRARY_RELWITHDEBINFO})
elseif(Stardis_LIBRARY_MINSIZEREL)
  set(Stardis_LIBRARY ${Stardis_LIBRARY_MINSIZEREL})
elseif(Stardis_LIBRARY_DEBUG)
  set(Stardis_LIBRARY ${Stardis_LIBRARY_DEBUG})
endif()

# Define the per configuration library fallback when not found
set(_configs RELEASE DEBUG RELWITHDEBINFO MINSIZEREL)
foreach(_cfg ${_configs})
  if(NOT Stardis_LIBRARY_${_cfg})
    get_property(_doc CACHE Stardis_LIBRARY_${_cfg} PROPERTY HELPSTRING)
    set(Stardis_LIBRARY_${_cfg} 
      ${Stardis_LIBRARY} CACHE PATH ${_doc} FORCE)
  endif()
endforeach()

# Create the imported library target
add_library(Stardis SHARED IMPORTED)

# Setup the properties of the imported target
if(CMAKE_HOST_WIN32)
  set(_import_prop IMPORTED_IMPLIB)
else()
  set(_import_prop IMPORTED_LOCATION)
endif()
set_target_properties(Stardis PROPERTIES
  ${_import_prop} ${Stardis_LIBRARY}
  ${_import_prop}_RELEASE ${Stardis_LIBRARY_RELEASE}
  ${_import_prop}_DEBUG ${Stardis_LIBRARY_DEBUG}
  ${_import_prop}_RELWITHDEBINFO ${Stardis_LIBRARY_RELWITHDEBINFO}
  ${_import_prop}_MINSIZEREL ${Stardis_LIBRARY_MINSIZEREL}
  INTERFACE_INCLUDE_DIRECTORIES ${Stardis_INCLUDE_DIR})

# Check the package
include(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(Stardis DEFAULT_MSG
  Stardis_INCLUDE_DIR
  Stardis_LIBRARY)

